@@ -13,30 +13,36 @@ using namespace Qt::Literals::StringLiterals;
 #include "categoryselectwidget.h"
 #include "config-kaddressbook.h"
 #include "configuredialog.h"
+#include "contactentitymimetypefiltermodel.h"
 #include "contactinfoproxymodel.h"
 #include "contactswitcher.h"
 #include "globalcontactmodel.h"
-#include "kaddressbook_options.h"
-#include "kaddressbookadaptor.h"
-#include "manageshowcollectionproperties.h"
-#include "modelcolumnmanager.h"
-#include "printing/printingwizard.h"
-#include "settings.h"
-#include "stylecontactlistdelegate.h"
-#include "widgets/quicksearchwidget.h"
-
 #include "importexport/contactselectiondialog.h"
 #include "importexport/plugin.h"
 #include "importexport/plugininterface.h"
 #include "importexport/pluginmanager.h"
+#include "kaddressbook_debug.h"
+#include "kaddressbook_options.h"
+#include "kaddressbookadaptor.h"
+#include "manageshowcollectionproperties.h"
+#include "modelcolumnmanager.h"
+#include "plugininterface/kaddressbookplugininterface.h"
+#include "printing/printingwizard.h"
+#include "settings.h"
+#include "stylecontactlistdelegate.h"
+#include "uistatesaver.h"
+#include "whatsnew/whatsnewtranslations.h"
+#include "widgets/quicksearchwidget.h"
+#if HAVE_ACTIVITY_SUPPORT
+#include "activities/accountactivities.h"
+#include "activities/activitiesmanager.h"
+#endif
 
-#include "contactentitymimetypefiltermodel.h"
 #include <Akonadi/GrantleeContactFormatter>
 #include <Akonadi/GrantleeContactGroupFormatter>
 #include <GrantleeTheme/GrantleeThemeManager>
 
-#include "uistatesaver.h"
-
+#include <PimCommon/PimUtil>
 #include <PimCommon/WhatsNewDialog>
 #include <PimCommonAkonadi/ImapAclAttribute>
 #include <PimCommonAkonadi/MailUtil>
@@ -55,7 +61,6 @@ using namespace Qt::Literals::StringLiterals;
 #endif
 #include <KContacts/Addressee>
 #include <PimCommon/PimUtil>
-#include <PimCommonAkonadi/ManageServerSideSubscriptionJob>
 #include <QPointer>
 
 #include <Akonadi/ContactGroupEditorDialog>
@@ -63,45 +68,49 @@ using namespace Qt::Literals::StringLiterals;
 #include <Akonadi/ContactViewer>
 #include <Akonadi/ContactsFilterProxyModel>
 #include <Akonadi/ContactsTreeModel>
+#include <Akonadi/ControlGui>
+#include <Akonadi/ETMViewStateSaver>
+#include <Akonadi/EntityMimeTypeFilterModel>
+#include <Akonadi/EntityTreeView>
+#include <Akonadi/ItemModifyJob>
+#include <Akonadi/MimeTypeChecker>
 #include <Akonadi/StandardContactActionManager>
+#ifndef FORCE_DISABLE_AKONADI_SEARCH
+#include <Debug/akonadisearchdebugdialog.h>
+#endif
 
-#include "kaddressbook_debug.h"
 #include <KActionCollection>
 #include <KActionMenu>
 #include <KCMultiDialog>
 #include <KCheckableProxyModel>
+#include <KColorSchemeManager>
 #include <KColorSchemeMenu>
+#include <KContacts/Addressee>
 #include <KContacts/ContactGroup>
 #include <KDescendantsProxyModel>
 #include <KLocalizedString>
+#include <KMessageBox>
 #include <KPluginMetaData>
 #include <KSelectionProxyModel>
 #include <KToggleAction>
-#include <KXMLGUIClient>
-#include <QAction>
-#include <QApplication>
-#include <QTextBrowser>
-
-#include "whatsnew/whatsnewtranslations.h"
-#include <Akonadi/ItemModifyJob>
-#include <KColorSchemeManager>
 #include <KWindowStateSaver>
+#include <KXMLGUIClient>
+
+#include <QAction>
 #include <QActionGroup>
+#include <QApplication>
 #include <QDBusConnection>
 #include <QDesktopServices>
 #include <QHBoxLayout>
 #include <QHeaderView>
+#include <QPointer>
 #include <QPrintDialog>
 #include <QPrintPreviewDialog>
 #include <QPrinter>
 #include <QSplitter>
 #include <QStackedWidget>
+#include <QTextBrowser>
 
-#include "plugininterface/kaddressbookplugininterface.h"
-#if HAVE_ACTIVITY_SUPPORT
-#include "activities/accountactivities.h"
-#include "activities/activitiesmanager.h"
-#endif
 namespace
 {
 static bool isStructuralCollection(const Akonadi::Collection &collection)
@@ -147,11 +156,15 @@ MainWidget::MainWidget(KXMLGUIClient *guiClient, QWidget *parent)
     , mXmlGuiClient(guiClient)
 {
     (void)new KaddressbookAdaptor(this);
-    QDBusConnection::sessionBus().registerObject(QStringLiteral("/KAddressBook"), this);
+    QDBusConnection::sessionBus().registerObject(u"/KAddressBook"_s, this);
 
     mManageShowCollectionProperties = new ManageShowCollectionProperties(this, this);
 
     Akonadi::AttributeFactory::registerAttribute<PimCommon::ImapAclAttribute>();
+    const auto entityTreeModel = GlobalContactModel::instance()->model();
+    connect(entityTreeModel, &Akonadi::EntityTreeModel::errorOccurred, this, [this](const QString &message) {
+        KMessageBox::error(this, message);
+    });
 
     KAddressBookPluginInterface::self()->setActionCollection(guiClient->actionCollection());
     KAddressBookPluginInterface::self()->initializePlugins();
@@ -360,14 +373,14 @@ void MainWidget::initializeImportExportPlugin(KActionCollection *collection)
 
     if (!importActions.isEmpty()) {
         auto importMenu = new KActionMenu(i18n("Import"), this);
-        collection->addAction(QStringLiteral("import_menu"), importMenu);
+        collection->addAction(u"import_menu"_s, importMenu);
         for (QAction *act : std::as_const(importActions)) {
             importMenu->addAction(act);
         }
     }
     if (!exportActions.isEmpty()) {
         auto exportMenu = new KActionMenu(i18n("Export"), this);
-        collection->addAction(QStringLiteral("export_menu"), exportMenu);
+        collection->addAction(u"export_menu"_s, exportMenu);
         for (QAction *act : std::as_const(exportActions)) {
             exportMenu->addAction(act);
         }
@@ -377,7 +390,7 @@ void MainWidget::initializeImportExportPlugin(KActionCollection *collection)
 void MainWidget::configure()
 {
     ConfigureDialog dlg(this);
-    const QList<KPluginMetaData> availablePlugins = KPluginMetaData::findPlugins(QStringLiteral("pim6/kcms/kaddressbook"));
+    const QList<KPluginMetaData> availablePlugins = KPluginMetaData::findPlugins(u"pim6/kcms/kaddressbook"_s);
     for (const KPluginMetaData &metaData : availablePlugins) {
         dlg.addModule(metaData);
     }
@@ -396,7 +409,7 @@ void MainWidget::handleCommandLine(const QStringList &arguments)
     kaddressbook_options(&parser);
     parser.process(arguments);
 
-    if (parser.isSet(QStringLiteral("import"))) {
+    if (parser.isSet(u"import"_s)) {
         const QStringList lst = parser.positionalArguments();
         for (const QString &urlStr : lst) {
             const QUrl url(QUrl::fromUserInput(urlStr));
@@ -407,10 +420,10 @@ void MainWidget::handleCommandLine(const QStringList &arguments)
                 }
             }
         }
-    } else if (parser.isSet(QStringLiteral("newcontact"))) {
+    } else if (parser.isSet(u"newcontact"_s)) {
         newContact();
-    } else if (parser.isSet(QStringLiteral("view"))) {
-        const auto url = QUrl{parser.value(QStringLiteral("view"))};
+    } else if (parser.isSet(u"view"_s)) {
+        const auto url = QUrl{parser.value(u"view"_s)};
         mPendingSelection = Akonadi::Item::fromUrl(url);
     }
 }
@@ -425,10 +438,10 @@ void MainWidget::delayedInit()
 {
     setViewMode(0); // get default from settings
 
-    const KConfigGroup group(Settings::self()->config(), QStringLiteral("UiState_ContactView"));
+    const KConfigGroup group(Settings::self()->config(), u"UiState_ContactView"_s);
     KAddressBook::UiStateSaver::restoreState(mItemView, group);
 
-    mXmlGuiClient->actionCollection()->action(QStringLiteral("options_show_qrcodes"))->setChecked(showQRCodes());
+    mXmlGuiClient->actionCollection()->action(u"options_show_qrcodes"_s)->setChecked(showQRCodes());
 
     connect(GlobalContactModel::instance()->model(), &QAbstractItemModel::modelAboutToBeReset, this, &MainWidget::saveState);
     connect(GlobalContactModel::instance()->model(), &QAbstractItemModel::modelReset, this, &MainWidget::restoreState);
@@ -444,7 +457,7 @@ MainWidget::~MainWidget()
     mModelColumnManager->store();
     saveSplitterStates();
 
-    KConfigGroup group(Settings::self()->config(), QStringLiteral("UiState_ContactView"));
+    KConfigGroup group(Settings::self()->config(), u"UiState_ContactView"_s);
     KAddressBook::UiStateSaver::saveState(mItemView, group);
 
     saveState();
@@ -462,7 +475,7 @@ void MainWidget::restoreState()
         auto saver = new Akonadi::ETMViewStateSaver;
         saver->setView(mCollectionView);
 
-        const KConfigGroup group(Settings::self()->config(), QStringLiteral("CollectionViewState"));
+        const KConfigGroup group(Settings::self()->config(), u"CollectionViewState"_s);
         saver->restoreState(group);
     }
 
@@ -471,7 +484,7 @@ void MainWidget::restoreState()
         auto saver = new Akonadi::ETMViewStateSaver;
         saver->setSelectionModel(mCollectionSelectionModel);
 
-        const KConfigGroup group(Settings::self()->config(), QStringLiteral("CollectionViewCheckState"));
+        const KConfigGroup group(Settings::self()->config(), u"CollectionViewCheckState"_s);
         saver->restoreState(group);
     }
 
@@ -486,7 +499,7 @@ void MainWidget::restoreState()
             saver->setCurrentItem(mPendingSelection);
             mPendingSelection = {};
         } else {
-            const KConfigGroup group(Settings::self()->config(), QStringLiteral("ItemViewState"));
+            const KConfigGroup group(Settings::self()->config(), u"ItemViewState"_s);
             saver->restoreState(group);
         }
     }
@@ -499,7 +512,7 @@ void MainWidget::saveState()
         Akonadi::ETMViewStateSaver saver;
         saver.setView(mCollectionView);
 
-        KConfigGroup group(Settings::self()->config(), QStringLiteral("CollectionViewState"));
+        KConfigGroup group(Settings::self()->config(), u"CollectionViewState"_s);
         saver.saveState(group);
         group.sync();
     }
@@ -509,7 +522,7 @@ void MainWidget::saveState()
         Akonadi::ETMViewStateSaver saver;
         saver.setSelectionModel(mCollectionSelectionModel);
 
-        KConfigGroup group(Settings::self()->config(), QStringLiteral("CollectionViewCheckState"));
+        KConfigGroup group(Settings::self()->config(), u"CollectionViewCheckState"_s);
         saver.saveState(group);
         group.sync();
     }
@@ -520,7 +533,7 @@ void MainWidget::saveState()
         saver.setView(mItemView);
         saver.setSelectionModel(mItemView->selectionModel());
 
-        KConfigGroup group(Settings::self()->config(), QStringLiteral("ItemViewState"));
+        KConfigGroup group(Settings::self()->config(), u"ItemViewState"_s);
         saver.saveState(group);
         group.sync();
     }
@@ -557,7 +570,7 @@ void MainWidget::setupGui()
     // the items view
     mItemView = new Akonadi::EntityTreeView();
     mItemView->setObjectName("ContactView"_L1);
-    mItemView->setDefaultPopupMenu(QStringLiteral("akonadi_itemview_contextmenu"));
+    mItemView->setDefaultPopupMenu(u"akonadi_itemview_contextmenu"_s);
     mItemView->setAlternatingRowColors(true);
     mMainWidgetSplitter2->addWidget(mItemView);
 
@@ -619,7 +632,7 @@ void MainWidget::setupGui()
 
 void MainWidget::initializePluginActions()
 {
-    KAddressBookPluginInterface::self()->initializePluginActions(QStringLiteral("kaddressbook"), mXmlGuiClient);
+    KAddressBookPluginInterface::self()->initializePluginActions(u"kaddressbook"_s, mXmlGuiClient);
 }
 
 bool MainWidget::canClose() const
@@ -642,12 +655,8 @@ void MainWidget::setupActions(KActionCollection *collection)
     KAddressBookPluginInterface::self()->setMainWidget(this);
     KAddressBookPluginInterface::self()->createPluginInterface();
 
-    mGrantleeThemeManager = new GrantleeTheme::ThemeManager(QStringLiteral("addressbook"),
-                                                            QStringLiteral("theme.desktop"),
-                                                            collection,
-                                                            QStringLiteral("kaddressbook/viewertemplates/"),
-                                                            QString(),
-                                                            this);
+    mGrantleeThemeManager =
+        new GrantleeTheme::ThemeManager(u"addressbook"_s, u"theme.desktop"_s, collection, u"kaddressbook/viewertemplates/"_s, QString(), this);
     connect(mGrantleeThemeManager, &GrantleeTheme::ThemeManager::grantleeThemeSelected, this, &MainWidget::slotGrantleeThemeSelected);
     connect(mGrantleeThemeManager, &GrantleeTheme::ThemeManager::updateThemes, this, &MainWidget::slotGrantleeThemesUpdated);
 
@@ -661,20 +670,20 @@ void MainWidget::setupActions(KActionCollection *collection)
     auto quicksearch = new QWidgetAction(this);
     quicksearch->setText(i18n("Quick search"));
     quicksearch->setDefaultWidget(mQuickSearchWidget);
-    collection->addAction(QStringLiteral("quick_search"), quicksearch);
+    collection->addAction(u"quick_search"_s, quicksearch);
 
     auto categoryFilter = new QWidgetAction(this);
     categoryFilter->setText(i18n("Category filter"));
     categoryFilter->setDefaultWidget(mCategorySelectWidget);
-    collection->addAction(QStringLiteral("category_filter"), categoryFilter);
+    collection->addAction(u"category_filter"_s, categoryFilter);
 
-    action = collection->addAction(QStringLiteral("select_all"));
+    action = collection->addAction(u"select_all"_s);
     action->setText(i18n("Select All"));
     collection->setDefaultShortcut(action, QKeySequence(Qt::CTRL | Qt::Key_A));
     action->setWhatsThis(i18n("Select all contacts in the current address book view."));
     connect(action, &QAction::triggered, mItemView, &Akonadi::EntityTreeView::selectAll);
 
-    auto qrtoggleAction = collection->add<KToggleAction>(QStringLiteral("options_show_qrcodes"));
+    auto qrtoggleAction = collection->add<KToggleAction>(u"options_show_qrcodes"_s);
     qrtoggleAction->setText(i18n("Show QR Codes"));
     qrtoggleAction->setWhatsThis(i18n("Show QR Codes in the contact."));
     connect(qrtoggleAction, &KToggleAction::toggled, this, &MainWidget::setQRCodeShow);
@@ -686,19 +695,19 @@ void MainWidget::setupActions(KActionCollection *collection)
     act->setData(1);
     collection->setDefaultShortcut(act, QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_1));
     act->setWhatsThis(i18n("Show a simple mode of the address book view."));
-    collection->addAction(QStringLiteral("view_mode_simple"), act);
+    collection->addAction(u"view_mode_simple"_s, act);
 
     act = new QAction(i18nc("@action:inmenu", "Two Columns"), mViewModeGroup);
     act->setCheckable(true);
     act->setData(2);
-    collection->addAction(QStringLiteral("view_mode_2columns"), act);
+    collection->addAction(u"view_mode_2columns"_s, act);
     collection->setDefaultShortcut(act, QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_2));
 
     act = new QAction(i18nc("@action:inmenu", "Three Columns"), mViewModeGroup);
     act->setCheckable(true);
     act->setData(3);
     collection->setDefaultShortcut(act, QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_3));
-    collection->addAction(QStringLiteral("view_mode_3columns"), act);
+    collection->addAction(u"view_mode_3columns"_s, act);
 
     connect(mViewModeGroup, &QActionGroup::triggered, this, &MainWidget::setActivateViewMode);
 
@@ -709,33 +718,30 @@ void MainWidget::setupActions(KActionCollection *collection)
 
     mQuickSearchAction = new QAction(i18nc("@action", "Set Focus to Quick Search"), this);
     // If change shortcut change in quicksearchwidget->lineedit->setPlaceholderText
-    collection->addAction(QStringLiteral("focus_to_quickseach"), mQuickSearchAction);
+    collection->addAction(u"focus_to_quickseach"_s, mQuickSearchAction);
     connect(mQuickSearchAction, &QAction::triggered, mQuickSearchWidget, &QuickSearchWidget::slotFocusQuickSearch);
     collection->setDefaultShortcut(mQuickSearchAction, QKeySequence(Qt::ALT | Qt::Key_Q));
 #ifndef FORCE_DISABLE_AKONADI_SEARCH
     if (!qEnvironmentVariableIsEmpty("KDEPIM_DEBUGGING")) {
-        action = collection->addAction(QStringLiteral("debug_akonadi_search"));
+        action = collection->addAction(u"debug_akonadi_search"_s);
         // Don't translate it. It's just for debug
-        action->setText(QStringLiteral("Debug Akonadi Search…"));
+        action->setText(u"Debug Akonadi Search…"_s);
         connect(action, &QAction::triggered, this, &MainWidget::slotDebugAkonadiSearch);
     }
 #endif
-    mServerSideSubscription = new QAction(QIcon::fromTheme(QStringLiteral("folder-bookmarks")), i18n("Serverside Subscription…"), this);
-    collection->addAction(QStringLiteral("serverside_subscription"), mServerSideSubscription);
-    connect(mServerSideSubscription, &QAction::triggered, this, &MainWidget::slotServerSideSubscription);
 
     auto manager = KColorSchemeManager::instance();
-    collection->addAction(QStringLiteral("colorscheme_menu"), KColorSchemeMenu::createMenu(manager, this));
+    collection->addAction(u"colorscheme_menu"_s, KColorSchemeMenu::createMenu(manager, this));
 
-    auto showWhatsNewAction = new QAction(QIcon::fromTheme(QStringLiteral("kaddressbook")), i18n("What's new"), this);
-    collection->addAction(QStringLiteral("whatsnew"), showWhatsNewAction);
+    auto showWhatsNewAction = new QAction(QIcon::fromTheme(u"kaddressbook"_s), i18n("What's new"), this);
+    collection->addAction(u"whatsnew"_s, showWhatsNewAction);
     connect(showWhatsNewAction, &QAction::triggered, this, &MainWidget::slotWhatsNew);
 }
 
 void MainWidget::slotWhatsNew()
 {
     WhatsNewTranslations translations;
-    PimCommon::WhatsNewDialog dlg(translations.createWhatsNewInfo(), this);
+    PimCommon::WhatsNewDialog dlg(translations.createWhatsNewInfo(), this, i18n("KAddressBook"));
     dlg.updateInformations();
     dlg.exec();
 }
@@ -839,16 +845,16 @@ void MainWidget::selectFirstItem()
 
 bool MainWidget::showQRCodes()
 {
-    KConfig config(QStringLiteral("akonadi_contactrc"));
-    KConfigGroup group(&config, QStringLiteral("View"));
+    KConfig config(u"akonadi_contactrc"_s);
+    KConfigGroup group(&config, u"View"_s);
     return group.readEntry("QRCodes", true);
 }
 
 void MainWidget::setQRCodeShow(bool on)
 {
     // must write the configuration setting first before updating the view.
-    KConfig config(QStringLiteral("akonadi_contactrc"));
-    KConfigGroup group(&config, QStringLiteral("View"));
+    KConfig config(u"akonadi_contactrc"_s);
+    KConfigGroup group(&config, u"View"_s);
     group.writeEntry("QRCodes", on);
     group.sync();
     if (mDetailsViewStack->currentWidget() == mContactDetails) {
@@ -954,7 +960,7 @@ void MainWidget::saveSplitterStates() const
         return;
     }
 
-    const QString groupName = QStringLiteral("UiState_MainWidgetSplitter_%1").arg(currentMode);
+    const QString groupName = u"UiState_MainWidgetSplitter_%1"_s.arg(currentMode);
     // qCDebug(KADDRESSBOOK_LOG) << "saving to group" << groupName;
     KConfigGroup group(Settings::self()->config(), groupName);
     KAddressBook::UiStateSaver::saveState(mMainWidgetSplitter1, group);
@@ -970,7 +976,7 @@ void MainWidget::restoreSplitterStates()
         return;
     }
 
-    const QString groupName = QStringLiteral("UiState_MainWidgetSplitter_%1").arg(currentMode);
+    const QString groupName = u"UiState_MainWidgetSplitter_%1"_s.arg(currentMode);
     // qCDebug(KADDRESSBOOK_LOG) << "restoring from group" << groupName;
     KConfigGroup group(Settings::self()->config(), groupName);
     KAddressBook::UiStateSaver::restoreState(mMainWidgetSplitter1, group);
@@ -981,7 +987,7 @@ void MainWidget::initGrantleeThemeName()
 {
     QString themeName = mGrantleeThemeManager->configuredThemeName();
     if (themeName.isEmpty()) {
-        themeName = QStringLiteral("default");
+        themeName = u"default"_s;
     }
     mFormatter->setGrantleeTheme(mGrantleeThemeManager->theme(themeName));
     mGroupFormatter->setGrantleeTheme(mGrantleeThemeManager->theme(themeName));
@@ -1081,24 +1087,11 @@ const Akonadi::Item::List MainWidget::collectSelectedAllContactsItem(QItemSelect
     return lst;
 }
 
-void MainWidget::slotServerSideSubscription()
-{
-    Akonadi::Collection collection = currentAddressBook();
-    if (collection.isValid()) {
-        auto job = new PimCommon::ManageServerSideSubscriptionJob(this);
-        job->setCurrentCollection(collection);
-        job->setParentWidget(this);
-        job->start();
-    }
-}
-
 void MainWidget::slotCurrentCollectionChanged(const Akonadi::Collection &col)
 {
     for (auto interface : std::as_const(mImportExportPluginInterfaceList)) {
         interface->setDefaultCollection(col);
     }
-    bool isOnline;
-    mServerSideSubscription->setEnabled(PimCommon::MailUtil::isImapFolder(col, isOnline));
 }
 
 #include "moc_mainwidget.cpp"
